#!perl
# (C) AbsoluteWord 2003-2004

use strict;

# print usage information

die <<"USAGE" unless @ARGV > 1;
Usage: $0 DictFileName DictID [trialdays]

If [trialdays] is not defined, the dictionary is compiled as freeware.
Add dictionary info to the "about.txt" file (if any).
Add abbreviations to the "abbr.txt" file (if any).
USAGE

# read the list of available languages
open LANGUAGES, "\@awmakerc.exe --help source_language |";
chomp( my @languages = <LANGUAGES> );
close LANGUAGES;

# remove technical info
while( shift( @languages ) !~ /^\s*$/ )
{
	next;
}

# choose source language
print "******   CHOOSE SOURCE LANGUAGE:   *******\n";
for( my $i = 1; $i <= @languages; $i++ )
{
	print "\[$i\] $languages[$i-1]\n";
}

print "Enter your choice (numeric, or empty for default): ";
chomp( my $choice = <STDIN> );

my $source_l = ( $choice =~ m|^\s*$| ) ? '' : "--source_language=$languages[$choice-1]";
print $source_l;

print "\nDoes the dictionary use HTML? (y/n) ";
chomp( $choice = <STDIN> );
my $is_html = ( lc $choice eq 'y' ) ? '--allow_html=1' : '--allow_html=0';

print "\nDoes the dictionary use Unicode? (y/n) ";
chomp( $choice = <STDIN> );
my $is_unicode = ( lc $choice eq 'y' ) ? '--unicode=1' : '--unicode=0';

my $about     = ( -e 'about.txt' ) ? "--aboutfile=\"about.txt\"" : '' ;
my $abbr      = ( -e 'abbr.txt'  ) ? "--abbrfile=\"abbr.txt\""  : '' ;
my $trialdays =   defined $ARGV[2] ? "--trialdays=$ARGV[2]"  : "--trialdays=0" ;

#### check for source format ####
my $source_format = undef;
open F, "<$ARGV[0]";
while( <F> )
{
	next if /^\s*$/;
	$source_format = /.\t./ ? '--source_format=tab' : '--source_format=csv';
	last;
}
close F;
print "\nChoosing $source_format\n";

# final step: processing files
print  "\nNow converting $ARGV[0] to $ARGV[1].pdb...\n";
system "awmakerc.exe --infile=$ARGV[0] $source_format --outfile=$ARGV[1].pdb --id=$ARGV[1] $trialdays $source_l $is_unicode $is_html $abbr $about";
